@@ -54,13 +54,13 @@ class Ui_MainWindow(QMainWindow):
         self.m_location.positionUpdated.connect(self.positionUpdated)
 
         if self.m_logfileInUse:
-            QMessageBox.information(self, self.tr("Rtap"), self.tr("No GPS support detected, using GPS data from a sample log file instead."))
+            QMessageBox.information(self, "Rtap", self.tr("Aucun module GPS n\'a \xe9t\xe9 trouv\xe9."))
     
         manager = QNetworkConfigurationManager()
         canStartIAP = (manager.capabilities() and QNetworkConfigurationManager.CanStartAndStopInterfaces)
         cfg = manager.defaultConfiguration()
         if not cfg.isValid() or (not canStartIAP and cfg.state() != QNetworkConfiguration.Active):
-            QMessageBox.information(self, self.tr("Rtap"), self.tr("Available Access Points not found."))
+            QMessageBox.information(self, "Rtap", self.tr("Aucune connexion n\'est possible."))
             return
 
         self.m_session = QNetworkSession(cfg, self)
@@ -69,6 +69,7 @@ class Ui_MainWindow(QMainWindow):
     # Start listening GPS position updates    
     def networkSessionOpened(self):
 #        print 'a'
+        
         self.m_location.startUpdates()
 #        print 'b'
 
@@ -77,8 +78,11 @@ class Ui_MainWindow(QMainWindow):
             coord = gpsPos.coordinate()
             self.m_latitude = coord.latitude()
             self.m_longitude = coord.longitude()
-            self.gps.setPos( (self.m_longitude*10-20)*500,-(self.m_latitude*10-488)*700)
+            self.gps.setPos( station.convertX(self.m_longitude),station.convertY(self.m_latitude))
             graph["GPS"].setPosXY(self.m_longitude, self.m_latitude)
+            if not self.gpsButton.fixed:
+                self.gpsButton.fixed = True
+                self.gpsButton.changeState()
             if gpsPos.attribute(QGeoPositionInfo.HorizontalAccuracy) < 80 or gpsPos.attribute(QGeoPositionInfo.VerticalAccuracy) < 80:
                 self.gpsButton.setPix('Good')
             else:
@@ -96,9 +100,9 @@ class Ui_MainWindow(QMainWindow):
 #        self.scene.removeItem(self.gps) 
 
     def gpsCenter(self):
-
-        self.view.goTo(QPointF(self.gps.x(),self.gps.y()),self.view.getScale())
-        self.view.animPar.start()
+        if self.gpsButton.fixed :
+            self.view.goTo(QPointF(self.gps.x(),self.gps.y()),self.view.getScale())
+            self.view.animPar.start()
         
     def play(self):
 
@@ -122,7 +126,7 @@ class Ui_MainWindow(QMainWindow):
 
             #Anime Zoom    
             
-            val = (5./self.view.getScale())**(.2)
+            val = (6./self.view.getScale())**(.2)
             animZoom = QPropertyAnimation (self.view, "scaling")
             animZoom.setDuration(_TEMPS_ANIM*2)
             animZoom.setEasingCurve(QEasingCurve.Linear)
@@ -177,10 +181,10 @@ class Ui_MainWindow(QMainWindow):
             h = self.height()
             Sx = (w/(dx+10))
             Sy = (h/(dy+10))
-            S = max(min(Sx,Sy,5.0),.21)
+            S = max(min(Sx,Sy,6.0),.2)
 
 
-            val = ((S) /5.)**(.15)
+            val = ((S) /6.)**(.17)
 
             
             animUnZoom = QPropertyAnimation (self.view, "scaling")
@@ -255,7 +259,7 @@ class Ui_MainWindow(QMainWindow):
 
         graph.clear()
         boole = (self.view.width() < self.view.height())
-        ligne = classes.diagLigne(self.Lignes,boole,self.view)
+        ligne = station.diagLigne(self.Lignes,boole,self.view)
         QObject.connect(ligne,SIGNAL("selection(PyQt_PyObject)"),self.selecLignesProcess)
         QObject.connect(self, SIGNAL("orientationChanged"), ligne.rotate)
         ligne.show()
@@ -412,7 +416,7 @@ class Ui_MainWindow(QMainWindow):
             if listeNom[0] == 'GPS':
                 self.gps.selec()
         elif len(listeNom) > 1:
-            Selec , ok = QInputDialog.getItem ( self.view, 'Liste de stations' , "Choisir la station :", listeNom, 0, False)
+            Selec , ok = QInputDialog.getItem ( self.view, self.tr("Liste des stations") , self.tr("Choisir la station :"), listeNom, 0, False)
             if ok:
                 self.setSelec(Selec)
                 if Selec == 'GPS':
@@ -438,7 +442,7 @@ class Ui_MainWindow(QMainWindow):
         if len(listeNom) == 1:
             return listeNom[0]
         elif len(listeNom) > 1:
-            Selec , ok = QInputDialog.getItem ( self.view, 'Liste de stations' , "Choisir la station :", listeNom, 0, False)
+            Selec , ok = QInputDialog.getItem ( self.view, self.tr("Liste des stations") , self.tr("Choisir la station :"), listeNom, 0, False)
             if ok:
                 return Selec
         
@@ -446,6 +450,7 @@ class Ui_MainWindow(QMainWindow):
         w = self.width()
         h = self.height()
         self.scene.unblur()
+        self.stop()
         for item in self.CheminItem:
             self.scene.removeItem(item)
         self.CheminItem=[]
@@ -488,139 +493,143 @@ class Ui_MainWindow(QMainWindow):
             graph[str(proche)].addCorres("GPS")
         else:
             self.Chemin, tps = dijkstra.algo(self.Selec[0],self.Selec[1],graph)
-
-        dep = self.Chemin[0]
-        for dest in self.Chemin[1:]:
-            idx = graph[dep].corres.index(dest)
-            line = QGraphicsLineItem ( 
-                    graph[dep].x() + _RAYON/2, 
-                    graph[dep].y() + _RAYON/2, 
-                    graph[dest].x() + _RAYON/2, 
-                    graph[dest].y() + _RAYON/2, 
-                    )
-            line.setPen(QPen(graph[dep].corresColor[idx], _RAYON/2))
-            self.CheminItem.append(line)
-            dep = dest
-        dep = self.Chemin[0]
-        for dest in self.Chemin:
-            gradient = QRadialGradient(graph[dest].x(),graph[dest].y(), _RAYON*1.5)
-            try:
-                idx = graph[dest].corres.index(dep)
-
-                gradient.setColorAt(0, graph[dest].corresColor[idx].lighter(200))
-                gradient.setColorAt(1, graph[dest].corresColor[idx])
-            except ValueError:
-                gradient.setColorAt(0, graph[dest].color.color().lighter(200))
-                gradient.setColorAt(1, graph[dest].color.color())
-            except AttributeError:
-                gradient.setColorAt(0, graph[dest].color.color())
-                gradient.setColorAt(1, graph[dest].color.color())
-                
-            ellipse = QGraphicsEllipseItem (graph[dest].x(), graph[dest].y(), _RAYON, _RAYON)
-
-            ellipse.setPen(QPen( gradient, _RAYON/2))
-            ellipse.setBrush(QBrush(gradient))
-            self.CheminItem.append(ellipse)
-            dep = dest
-        dep = self.Chemin[0]
-
-        minH = graph[self.Chemin[0]].x()
-        maxH = graph[self.Chemin[0]].x()
-        minV = graph[self.Chemin[0]].y()
-        maxV = graph[self.Chemin[0]].y()
-
-        for dest in self.Chemin:
-            if not dest[:-4] in graph[dep].name or dest == dep:
-                if dest[-1] == ']':
-                    txt = QGraphicsTextItem (dest[:-4])
-                else:
-                    txt = QGraphicsTextItem (dest)
-                txt.setPos(graph[dest].pos())
-                txt.setFont(QFont ( "Nokia Sans",_RAYON/2 ,63 ))
-    
+        if tps == -1:
+            QMaemo5InformationBox.information( self, self.tr("D\xe9sol\xe9, aucun chemin n\'a \xe9t\xe9 trouv\xe9."))
+            self.scene.unblur()
+            self.panAction.playX(self.width())
+        else:
+            dep = self.Chemin[0]
+            for dest in self.Chemin[1:]:
+                idx = graph[dep].corres.index(dest)
+                line = QGraphicsLineItem ( 
+                        graph[dep].x() + _RAYON/2, 
+                        graph[dep].y() + _RAYON/2, 
+                        graph[dest].x() + _RAYON/2, 
+                        graph[dest].y() + _RAYON/2, 
+                        )
+                line.setPen(QPen(graph[dep].corresColor[idx], _RAYON/2))
+                self.CheminItem.append(line)
+                dep = dest
+            dep = self.Chemin[0]
+            for dest in self.Chemin:
+                gradient = QRadialGradient(graph[dest].x(),graph[dest].y(), _RAYON*1.5)
                 try:
                     idx = graph[dest].corres.index(dep)
     
-                    txt.setDefaultTextColor(graph[dest].corresColor[idx])
+                    gradient.setColorAt(0, graph[dest].corresColor[idx].lighter(200))
+                    gradient.setColorAt(1, graph[dest].corresColor[idx])
                 except ValueError:
-                    txt.setDefaultTextColor(graph[dest].color.color())
+                    gradient.setColorAt(0, graph[dest].color.color().lighter(200))
+                    gradient.setColorAt(1, graph[dest].color.color())
                 except AttributeError:
-                    txt.setDefaultTextColor(graph[dest].color.color())
+                    gradient.setColorAt(0, graph[dest].color.color())
+                    gradient.setColorAt(1, graph[dest].color.color())
                     
-                if dest[-1] == ']':
-                    txtOmbre = QGraphicsTextItem (dest[:-4])
-                else:
-                    txtOmbre = QGraphicsTextItem (dest)
-                txtOmbre.setPos(graph[dest].x()-.25, graph[dest].y()+.25)
-                txtOmbre.setDefaultTextColor(Qt.black)
-                txtOmbre.setFont(QFont ( "Nokia Sans",_RAYON/2 ,63 ))
+                ellipse = QGraphicsEllipseItem (graph[dest].x(), graph[dest].y(), _RAYON, _RAYON)
     
-                self.CheminItem.append(txtOmbre)
-                self.CheminItem.append(txt)
-
-                minH = min(minH,graph[dest].x())
-                maxH = max(maxH,graph[dest].x())
-                minV = min(minV,graph[dest].y())
-                maxV = max(maxV,graph[dest].y())
-
-            dep = dest
-
-        for item in self.CheminItem:
-            self.scene.addItem(item)
-        self.scene.update()
-        self.panAction.toggling()
-
-        self.Temps.setText("Environ "+ str(int(tps/60)) + " min.")
-        self.Temps.resize(200,40)
-        self.Temps.show()
-        self.animTemps.setKeyValueAt(0, QPoint(10, -50) )
-        self.animTemps.setKeyValueAt(1, QPoint(10, 0) )
-        self.animTemps.start()
+                ellipse.setPen(QPen( gradient, _RAYON/2))
+                ellipse.setBrush(QBrush(gradient))
+                self.CheminItem.append(ellipse)
+                dep = dest
+            dep = self.Chemin[0]
     
-
-            #Anim UnCenter 
-
-        animUnCenter = QPropertyAnimation (self.view, "center")
-        animUnCenter.setDuration(_TEMPS_ANIM)
-        animUnCenter.setEasingCurve(QEasingCurve.OutQuad)
-        animUnCenter.setKeyValueAt(0, self.view.getCenter())
-            
-        dx = abs(maxH - minH)
-        dy = abs(maxV - minV)
-            
-        x = (maxH + minH)/2
-        y = (maxV + minV)/2
-        animUnCenter.setKeyValueAt(1, QPointF(  x,  y ))
-
-            #Anime UnZoom    
-            
-        w = self.width()
-        h = self.height()
-        Sx = (w/(dx+10))
-        Sy = (h/(dy+10))
-        S = max(min(Sx,Sy,5.0),.21)
-
-        val = ((S) /self.view.getScale())**(.1)
-            
-        animUnZoom = QPropertyAnimation (self.view, "scaling")
-        animUnZoom.setDuration(_TEMPS_ANIM)
-        animUnZoom.setEasingCurve(QEasingCurve.Linear)
-        animUnZoom.setKeyValueAt(0, val)
-        animUnZoom.setKeyValueAt(1, val)
-
-        animParOut = QParallelAnimationGroup()
-        animParOut.addAnimation(animUnCenter)
-        animParOut.addAnimation(animUnZoom)
+            minH = graph[self.Chemin[0]].x()
+            maxH = graph[self.Chemin[0]].x()
+            minV = graph[self.Chemin[0]].y()
+            maxV = graph[self.Chemin[0]].y()
+    
+            for dest in self.Chemin:
+                if not dest[:-4] in graph[dep].name or dest == dep:
+                    if dest[-1] == ']':
+                        txt = QGraphicsTextItem (dest[:-4])
+                    else:
+                        txt = QGraphicsTextItem (dest)
+                    txt.setPos(graph[dest].pos())
+                    txt.setFont(QFont ( "Nokia Sans",_RAYON/2 ,63 ))
         
-        self.view.animSeq.stop()
-        self.view.animSeq.clear()
-        self.view.animSeq.addAnimation(animParOut)
-        self.view.animSeq.start()
+                    try:
+                        idx = graph[dest].corres.index(dep)
+        
+                        txt.setDefaultTextColor(graph[dest].corresColor[idx])
+                    except ValueError:
+                        txt.setDefaultTextColor(graph[dest].color.color())
+                    except AttributeError:
+                        txt.setDefaultTextColor(graph[dest].color.color())
+                        
+                    if dest[-1] == ']':
+                        txtOmbre = QGraphicsTextItem (dest[:-4])
+                    else:
+                        txtOmbre = QGraphicsTextItem (dest)
+                    txtOmbre.setPos(graph[dest].x()-.25, graph[dest].y()+.25)
+                    txtOmbre.setDefaultTextColor(Qt.black)
+                    txtOmbre.setFont(QFont ( "Nokia Sans",_RAYON/2 ,63 ))
+        
+                    self.CheminItem.append(txtOmbre)
+                    self.CheminItem.append(txt)
+    
+                    minH = min(minH,graph[dest].x())
+                    maxH = max(maxH,graph[dest].x())
+                    minV = min(minV,graph[dest].y())
+                    maxV = max(maxV,graph[dest].y())
+    
+                dep = dest
+    
+            for item in self.CheminItem:
+                self.scene.addItem(item)
+            self.scene.update()
+            self.panAction.toggling()
+    
+            self.Temps.setText(self.tr("Environ ")+ str(int(tps/60)) + " min.")
+            self.Temps.resize(200,40)
+            self.Temps.show()
+            self.animTemps.setKeyValueAt(0, QPoint(10, -50) )
+            self.animTemps.setKeyValueAt(1, QPoint(10, 0) )
+            self.animTemps.start()
+    
 
-        try:
-            graph[str(proche)].removeCorres("GPS")
-        except UnboundLocalError:
-            return
+            #Anim Center 
+
+            animCenter = QPropertyAnimation (self.view, "center")
+            animCenter.setDuration(_TEMPS_ANIM)
+            animCenter.setEasingCurve(QEasingCurve.OutQuad)
+            animCenter.setKeyValueAt(0, self.view.getCenter())
+                
+            dx = abs(maxH - minH)
+            dy = abs(maxV - minV)
+                
+            x = (maxH + minH)/2
+            y = (maxV + minV)/2
+            animCenter.setKeyValueAt(1, QPointF(  x,  y ))
+    
+            #Anime Zoom    
+            
+            w = self.width()
+            h = self.height()
+            Sx = (w/(dx+10))
+            Sy = (h/(dy+10))
+            S = max(min(Sx,Sy,6.0),.2)
+
+            val = ((S) /self.view.getScale())**(.1)
+                
+            animZoom = QPropertyAnimation (self.view, "scaling")
+            animZoom.setDuration(_TEMPS_ANIM)
+            animZoom.setEasingCurve(QEasingCurve.Linear)
+            animZoom.setKeyValueAt(0, val)
+            animZoom.setKeyValueAt(1, val)
+
+            animPar = QParallelAnimationGroup()
+            animPar.addAnimation(animCenter)
+            animPar.addAnimation(animZoom)
+        
+            self.view.animSeq.stop()
+            self.view.animSeq.clear()
+            self.view.animSeq.addAnimation(animPar)
+            self.view.animSeq.start()
+
+            try:
+                graph[str(proche)].removeCorres("GPS")
+            except UnboundLocalError:
+                return
         
         
 
@@ -699,34 +708,13 @@ class Ui_MainWindow(QMainWindow):
                 
     def drawFleuve(self):
         #Fleuve
+        fleuveListX = station.FleuvesX
+        fleuveListY = station.FleuvesY
         fleuve = QPainterPath()
-        fleuve.moveTo(station.SeineX[0], station.SeineY[0])
-        l = len(station.SeineX)
-        k = 1
-        while k != l:
-            fleuve.lineTo(station.SeineX[k], station.SeineY[k])
-            k += 1
-
-        fleuve.moveTo(station.OiseX[0], station.OiseY[0])
-        l = len(station.OiseX)
-        k = 1
-        while k != l:
-            fleuve.lineTo(station.OiseX[k], station.OiseY[k])
-            k += 1
-
-        fleuve.moveTo(station.MarneX[0], station.MarneY[0])
-        l = len(station.MarneX)
-        k = 1
-        while k != l:
-            fleuve.lineTo(station.MarneX[k], station.MarneY[k])
-            k += 1
-           
-        fleuve.moveTo(station.SeineIleX[0], station.SeineIleY[0])
-        l = len(station.SeineIleX)
-        k = 1
-        while k != l:
-            fleuve.lineTo(station.SeineIleX[k], station.SeineIleY[k])
-            k += 1
+        for k in range(len(fleuveListX)):
+            fleuve.moveTo(fleuveListX[k][0],fleuveListY[k][0])
+            for point in range(len(fleuveListX[k])-1):
+                fleuve.lineTo(fleuveListX[k][point+1],fleuveListY[k][point+1])
            
         self.scene.addPath(fleuve, QPen( QColor(165,191,221), _RAYON*.8))
 
@@ -739,18 +727,18 @@ class Ui_MainWindow(QMainWindow):
         self.Selec = ('','')
         self.CheminItem = []
         self.Chemin = []
-        self.Lignes = range(25)#[station.GPS] + station.Metro + station.Rer+ station.Tram
+        self.Lignes = range(len(station.FullListe))#[station.GPS] + station.Metro + station.Rer+ station.Tram
 
 
 ########## GPS
 
 #        self.gps = graph["GPS"]
         self.gps = classes.Gps()
+        self.gps.setPos( 0,0)
 
 ########## Scene
         
         self.scene = classes.Carte(self)
-#        self.scene.setSceneRect(-815.90800894434585, -2585.2493331816809, 5397.5130039461728, 3900.3854289115216)
         
         self.buildGraph()
         self.drawGraph()
@@ -806,19 +794,19 @@ class Ui_MainWindow(QMainWindow):
         menubar = QMenuBar(self)
         self.setMenuBar(menubar)
         
-        menuChercher = QAction("Recherche",self)
+        menuChercher = QAction(self.tr("Recherche"),self)
         menubar.addAction(menuChercher)
         QObject.connect(menuChercher, SIGNAL("triggered()"), self.search)
 
-        menuLignes = QAction("Lignes",self)
+        menuLignes = QAction(self.tr("Lignes"),self)
         menubar.addAction(menuLignes)
         QObject.connect(menuLignes, SIGNAL("triggered()"), self.selecLignes)
 
-        menuAide = QAction("Aide",self)
+        menuAide = QAction(self.tr("Aide"),self)
         menubar.addAction(menuAide)
         QObject.connect(menuAide, SIGNAL("triggered()"), self.aide)
 
-        menuAbout = QAction("\xc0 Propos",self)
+        menuAbout = QAction(self.tr("\xc0 Propos"),self)
         menubar.addAction(menuAbout)
         QObject.connect(menuAbout, SIGNAL("triggered()"), self.about)
 
@@ -832,6 +820,8 @@ class Ui_MainWindow(QMainWindow):
         self.view.update()
 
         self.setCentralWidget(self.view)
+        app.setOverrideCursor(QCursor(Qt.CrossCursor))
+        
 
         QObject.connect(app.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         
